<?php

if (!defined('ABSPATH')) {
    exit;
}

class TransactionCloudCustomizeProduct
{
    public $productId;
    public $prices;
    public $description;
    public $payload;
    public $userFirstName;
    public $userLastName;
    public $userEmail;
    public $transactionIdToMigrate;

    /**
     * @param string $productId
     */
    function __construct($productId)
    {
        $this->productId = $productId;
    }

    /**
     * @param TransactionCloudPrice price
     *
     * @return TransactionCloudCustomizeProduct
     */
    public function addPrice($price)
    {
        $this->prices[] = $price;

        return $this;
    }

    /**
     * @return string
     */
    public function getProductId()
    {
        return $this->productId;
    }

    /**
     * @param string $description
     *
     * @return TransactionCloudCustomizeProduct
     */
    public function setDescription($description)
    {
        $this->description = $description;

        return $this;
    }

    /**
     * @param string $payload
     *
     * @return TransactionCloudCustomizeProduct
     */
    public function setPayload($paylad)
    {
        $this->payload = $paylad;

        return $this;
    }

    /**
     * @param array $prices
     *
     * @return TransactionCloudCustomizeProduct
     */
    public function setPrices(array $prices)
    {
        $this->prices = $prices;

        return $this;
    }

    /**
     * @param string $transactionId
     *
     * @return TransactionCloudCustomizeProduct
     */
    public function setTransactionIdToMigrate($transactionId)
    {
        $this->transactionIdToMigrate = $transactionId;

        return $this;
    }

    /**
     * @param string $firstName
     *
     * @return TransactionCloudCustomizeProduct
     */
    public function setUserFirstName($firstName)
    {
        $this->userFirstName = $firstName;

        return $this;
    }

    /**
     * @param string $firstName
     *
     * @return TransactionCloudCustomizeProduct
     */
    public function setUserLastName($lastName)
    {
        $this->userLastName = $lastName;

        return $this;
    }

    /**
     * @param string $firstName
     *
     * @return TransactionCloudCustomizeProduct
     */
    public function setUserEmail($email)
    {
        $this->userEmail = $email;

        return $this;
    }

    /**
     * @return array|null
     */
    public function getCustomizationParams()
    {
        $params = [];

        if (isset($this->prices) && count($this->prices) > 0) {
            $params['prices'] = $this->prices;
        }

        if (isset($this->description) && $this->description != '') {
            $params['description'] = $this->description;
        }

        if (isset($this->payload) && $this->payload != '') {
            $params['payload'] = $this->payload;
        }

        if (isset($this->transactionIdToMigrate) && $this->transactionIdToMigrate != '') {
            $params['transactionIdToMigrate'] = $this->transactionIdToMigrate;
        }

        if (isset($this->userEmail) && $this->userEmail != '') {
            $params['userMail'] = $this->userEmail;
        }

        if (isset($this->userFirstName) && $this->userFirstName != '') {
            $params['userFirstName'] = $this->userFirstName;
        }

        if (isset($this->userLastName) && $this->userLastName != '') {
            $params['userLastName'] = $this->userLastName;
        }

        if (count($params) < 1) {
            return null;
        }

        return $params;
    }
}
